@@ -85,7 +85,7 @@ class Interaction(moving.STObject, VideoFilenameAddable):
                       'm',
                       'm',
                       'rad',
-                      'm/s',
+                      'km/h',
                       '',
                       's',
                       '',
@@ -224,9 +224,12 @@ class Interaction(moving.STObject, VideoFilenameAddable):
 
     def categorize(self, velocityAngleTolerance, parallelAngleTolerance, headonCollisionCourseAngleTolerance = None):
         '''Computes the interaction category by instant
-        velocityAngleTolerance and parallelAngleTolerance in radian
-        velocityAngleTolerance: indicates the angle threshold for rear and head on (180-velocityAngleTolerance), as well as the maximum collision course angle for head on
-        velocityAngleTolerance: indicates the angle between velocity vector (average for parallel) and position vector'''
+        all 3 angle arguments in radian
+        velocityAngleTolerance: indicates the angle threshold for rear and head on (180-velocityAngleTolerance), as well as the maximum collision course angle for head on (if headonCollisionCourseAngleTolerance is None)
+        parallelAngleTolerance: indicates the angle between velocity vector (average for parallel) and position vector
+
+        an instant may not be categorized if it matches the side definition (angle)
+        but the distance is growing (at least one user is probably past the point of trajectory crossing)'''
         parallelAngleToleranceCosine = np.cos(parallelAngleTolerance)
         if headonCollisionCourseAngleTolerance is None:
             headonCollisionCourseAngleTolerance = velocityAngleTolerance
